@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 use Redis;
 use List::MoreUtils qw( bsearch );
@@ -574,7 +574,7 @@ L<http://redis.io/topics/cluster-spec>
 
 =head2 new( %params )
 
-  my $cluster = AnyEvent::RipeRedis::Cluster->new(
+  my $cluster = Redis::ClusterRider->new(
     startup_nodes => [
       'localhost:7000',
       'localhost:7001',
@@ -749,7 +749,7 @@ the C<refresh_interval> to default value.
 
 =head1 SERVICE FUNCTIONS
 
-Service functions provided by AnyEvent::RipeRedis::Cluster can be imported.
+Service functions provided by l<Redis::ClusterRider> can be imported.
 
   use Redis::ClusterRider qw( crc16 hash_slot );
 
